# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.contrib import admin

from matchups.models import Matchup


class MatchupAdmin(admin.ModelAdmin):
	list_display = ('title', 'email', 'description', 'featured', 'created_on')


admin.site.register(Matchup, MatchupAdmin)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.http import HttpResponseBadRequest, JsonResponse
from django.views.decorators.cache import cache_page

import pybomojo


@cache_page(60 * 60 * 24)
def search(request):
    if 'title' not in request.GET:
        return HttpResponseBadRequest('"title" is required')

    search_term = request.GET['title']
    results = pybomojo.search_movies(search_term)

    # Move exact result to the top. This is very inefficient, but it'll get the
    # job done for now. (The more efficient code would be slightly uglier.)
    results = ([result for result in results if result['exact']] +
               [result for result in results if not result['exact']])

    return JsonResponse({'results': results})


@cache_page(60 * 15)
def box_office(request, movie_id):
    try:
        return JsonResponse(pybomojo.get_box_office(movie_id))
    except pybomojo.MovieNotFound as e:
        return JsonResponse({'errors': [str(e)]}, status=404)



from django.test import TestCase

from matchups.forms import MatchupForm


class MatchupFormTest(TestCase):
    def test_happy_path(self):
        form = MatchupForm({
            'title': 'foo trilogy',
            'email': 'dan@example.com',
            'description': 'The entire foo trilogy',
            'movies': ['foo', 'bar'],
            'period': '30d'
        })

        self.assertTrue(form.is_valid())

        matchup = form.save()

        self.assertEqual(matchup.title, 'foo trilogy')
        self.assertEqual(matchup.email, 'dan@example.com')
        self.assertEqual(matchup.description, 'The entire foo trilogy')
        self.assertEqual(matchup.movies, ['foo', 'bar'])
        self.assertEqual(matchup.period, '30d')

    def test_minimal_fields(self):
        form = MatchupForm({
            'title': 'foo vs bar',
            'movies': ['foo', 'bar']
        })

        self.assertTrue(form.is_valid())

        matchup = form.save()

        self.assertEqual(matchup.title, 'foo vs bar')
        self.assertEqual(matchup.email, '')
        self.assertEqual(matchup.description, '')
        self.assertEqual(matchup.movies, ['foo', 'bar'])
        self.assertEqual(matchup.period, '')

    def test_title_cannot_be_omitted(self):
        form = MatchupForm({
            'description': 'The entire foo trilogy',
            'movies': ['foo1', 'foo2', 'foo3']
        })

        self.assertFalse(form.is_valid())
        self.assertIn('title', form.errors)
        self.assertIn('required', *form.errors['title'])

    def test_title_cannot_be_blank(self):
        form = MatchupForm({
            'title': '',
            'description': 'The entire foo trilogy',
            'movies': ['foo1', 'foo2', 'foo3']
        })
        self.assertFalse(form.is_valid())
        self.assertIn('title', form.errors)
        self.assertIn('required', *form.errors['title'])

    def test_movies_cannot_be_omitted(self):
        form = MatchupForm({
            'title': 'foo vs bar'
        })
        self.assertFalse(form.is_valid())
        self.assertIn('movies', form.errors)
        self.assertIn('required', *form.errors['movies'])

    def test_movies_cannot_be_empty(self):
        form = MatchupForm({
            'title': 'foo vs bar',
            'movies': []
        })
        self.assertFalse(form.is_valid())
        self.assertIn('movies', form.errors)
        self.assertIn('required', *form.errors['movies'])

    def test_email_must_be_valid_if_provided(self):
        form = MatchupForm({
            'title': 'foo vs bar',
            'email': 'blah',
            'movies': ['foo', 'bar']
        })
        self.assertFalse(form.is_valid())
        self.assertIn('email', form.errors)
        self.assertIn('valid', *form.errors['email'])

    def test_period_must_be_valid_if_provided(self):
        form = MatchupForm({
            'title': 'foo vs bar',
            'movies': ['foo', 'bar'],
            'period': 'blah'
        })
        self.assertFalse(form.is_valid())
        self.assertIn('period', form.errors)
        self.assertIn('valid', *form.errors['period'])



from distutils.core import setup
from setuptools import find_packages

requirements = [
    'Django>=1.11.3,<2',
    # Require Postgres -- can't use sqlite because some models use
    # django.contrib.postgres.fields.ArrayField
    'psycopg2==2.7.1',
    'pybomojo==0.1.1',
    'python-slugify>=1.2.4,<2',
]

test_requirements = [
    # Used in test settings
    'dj-database-url==0.4.2',

    # Libraries used by the tests themselves
    'freezegun==0.3.10',
    'mock==2.0.0',

    # Libraries used to discover/run the tests
    'pytest==3.2.0',
    'pytest-django==3.1.2',
]

setup(
    name='bomojo',
    packages=find_packages(),
    version='0.1.4',
    description='Django app for getting movie box office data',
    install_requires=requirements,
    tests_require=test_requirements,
    extras_require={
        'test': test_requirements
    },
    author='Dan Tao',
    author_email='daniel.tao@gmail.com',
    url='https://bitbucket.org/dtao/pybomojo',
    keywords=[],
    classifiers=[],
)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.forms import ModelForm

from matchups.models import Matchup


class MatchupForm(ModelForm):
    class Meta:
        model = Matchup
        fields = ['email', 'title', 'description', 'movies', 'period']
